=======
GroupBy
=======

This namespace comes available by calling `LazyFrame.group_by(..)`.

.. currentmodule:: polars.lazyframe.group_by

.. autosummary::
   :toctree: api/

    LazyGroupBy.agg
    LazyGroupBy.all
    LazyGroupBy.apply
    LazyGroupBy.count
    LazyGroupBy.first
    LazyGroupBy.head
    LazyGroupBy.last
    LazyGroupBy.map_groups
    LazyGroupBy.max
    LazyGroupBy.mean
    LazyGroupBy.median
    LazyGroupBy.min
    LazyGroupBy.n_unique
    LazyGroupBy.quantile
    LazyGroupBy.sum
    LazyGroupBy.tail
